package com.jiuqi.util;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.GregorianCalendar;

/* loaded from: com_jiuqi_util.jar:com/jiuqi/util/DateUtil.class */
public class DateUtil {
    private static SimpleDateFormat formatter1;
    private static SimpleDateFormat formatter2;
    private static SimpleDateFormat formatter3;
    private static SimpleDateFormat formatter4;
    private static SimpleDateFormat formatter5;
    private static SimpleDateFormat[] formatters;
    private static int[][] _LunarCal = {new int[]{23, 3, 2, 17, 1, 0, 0, 1, 0, 0, 1, 1, 0, 1, 1, 1}, new int[]{41, 0, 4, 23, 1, 0, 0, 1, 0, 0, 1, 0, 1, 1, 1, 0, 1}, new int[]{30, 7, 5, 28, 1, 1, 0, 0, 1, 0, 0, 1, 0, 1, 1, 0, 1}, new int[]{49, 0, 6, 33, 1, 1, 0, 0, 1, 0, 0, 1, 0, 1, 0, 1, 1}, new int[]{38, 0, 0, 38, 1, 1, 0, 1, 0, 1, 0, 0, 1, 0, 1, 0, 1}, new int[]{26, 6, 2, 44, 1, 1, 0, 1, 1, 0, 1, 0, 0, 1, 0, 1}, new int[]{45, 0, 3, 49, 1, 0, 1, 1, 0, 1, 0, 1, 0, 1, 0, 1}, new int[]{35, 0, 4, 54, 0, 1, 0, 1, 0, 1, 1, 0, 1, 0, 1, 0, 1}, new int[]{24, 4, 5, 59, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 1, 1}, new int[]{43, 0, 0, 5, 0, 0, 1, 0, 0, 1, 0, 1, 1, 1, 0, 1, 1}, new int[]{32, 0, 1, 10, 1, 0, 0, 1, 0, 0, 1, 0, 1, 1, 0, 1, 1}, new int[]{21, 2, 2, 15, 1, 1, 0, 0, 1, 0, 0, 1, 0, 1, 0, 1, 1}, new int[]{40, 0, 3, 20, 1, 0, 1, 0, 1, 0, 0, 1, 0, 1, 0, 1, 1}, new int[]{28, 7, 5, 26, 1, 0, 1, 1, 0, 1, 0, 0, 1, 0, 1, 0, 1}, new int[]{47, 0, 6, 31, 0, 1, 1, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1}, new int[]{36, 0, 0, 36, 1, 0, 1, 1, 0, 1, 0, 1, 0, 1, 0, 1}, new int[]{26, 5, 1, 41, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 1, 0, 1}, new int[]{44, 0, 3, 47, 0, 1, 0, 0, 1, 1, 0, 1, 1, 0, 1, 0, 1}, new int[]{33, 0, 4, 52, 1, 0, 1, 0, 0, 1, 0, 1, 1, 0, 1, 1}, new int[]{23, 3, 5, 57, 0, 1, 0, 1, 0, 0, 1, 0, 1, 0, 1, 1, 1}, new int[]{42, 0, 6, 2, 0, 1, 0, 1, 0, 0, 1, 0, 1, 0, 1, 1, 1}, new int[]{30, 8, 1, 8, 1, 0, 1, 0, 1, 0, 0, 1, 0, 1, 0, 1}, new int[]{48, 0, 2, 13, 1, 1, 1, 0, 1, 0, 0, 1, 0, 1, 0, 1}, new int[]{38, 0, 3, 18, 0, 1, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1}, new int[]{27, 6, 4, 23, 1, 0, 1, 0, 1, 1, 0, 1, 0, 1, 0, 1}, new int[]{45, 0, 6, 29, 1, 0, 1, 0, 1, 0, 1, 1, 0, 1, 0, 1}, new int[]{35, 0, 0, 34, 0, 1, 0, 0, 1, 0, 1, 1, 0, 1, 1, 0, 1}, new int[]{24, 4, 1, 39, 1, 0, 1, 0, 0, 1, 0, 1, 0, 1, 1, 1}, new int[]{43, 0, 2, 44, 1, 0, 1, 0, 0, 1, 0, 1, 0, 1, 1, 1}, new int[]{32, 0, 4, 50, 0, 1, 0, 1, 0, 0, 1, 0, 0, 1, 1, 0, 1}, new int[]{20, 3, 5, 55, 1, 1, 1, 0, 1, 0, 0, 1, 0, 0, 1, 1}, new int[]{39, 0, 6, 0, 1, 1, 0, 1, 1, 0, 0, 1, 0, 1, 0, 1}, new int[]{29, 7, 0, 5, 0, 1, 0, 1, 1, 0, 1, 0, 1, 0, 1, 0, 1}, new int[]{47, 0, 2, 11, 0, 1, 0, 1, 0, 1, 1, 0, 1, 0, 1, 0, 1}, new int[]{36, 0, 3, 16, 1, 0, 0, 1, 0, 1, 1, 0, 1, 1, 0, 1}, new int[]{26, 5, 4, 21, 0, 1, 0, 0, 1, 0, 1, 0, 1, 1, 1, 0, 1}, new int[]{45, 0, 5, 26, 0, 1, 0, 0, 1, 0, 1, 0, 1, 1, 0, 1, 1}, new int[]{33, 0, 0, 32, 1, 0, 1, 0, 0, 1, 0, 0, 1, 1, 0, 1, 1}, new int[]{22, 4, 1, 37, 1, 1, 0, 1, 0, 0, 1, 0, 0, 1, 1, 0, 1}, new int[]{41, 0, 2, 42, 1, 1, 0, 1, 0, 0, 1, 0, 0, 1, 0, 1, 1}, new int[]{30, 8, 3, 47, 1, 1, 0, 1, 0, 1, 0, 1, 0, 0, 1, 0, 1}, new int[]{48, 0, 5, 53, 1, 0, 1, 1, 0, 1, 0, 1, 0, 1, 0, 0, 1}, new int[]{37, 0, 6, 58, 1, 0, 1, 1, 0, 1, 1, 0, 1, 0, 1, 0, 1}, new int[]{27, 6, 0, 3, 1, 0, 0, 1, 0, 1, 1, 0, 1, 1, 0, 1}, new int[]{46, 0, 1, 8, 1, 0, 0, 1, 0, 1, 0, 1, 1, 0, 1, 1}, new int[]{35, 0, 3, 14, 0, 1, 0, 0, 1, 0, 0, 1, 1, 0, 1, 1, 1}, new int[]{24, 4, 4, 19, 1, 0, 1, 0, 0, 1, 0, 0, 1, 0, 1, 1, 1}, new int[]{43, 0, 5, 24, 1, 0, 1, 0, 0, 1, 0, 0, 1, 0, 1, 1, 1}, new int[]{32, 10, 6, 29, 1, 0, 1, 1, 0, 0, 1, 0, 0, 1, 0, 1, 1}, new int[]{50, 0, 1, 35, 0, 1, 1, 0, 1, 0, 1, 0, 0, 1, 0, 1}, new int[]{39, 0, 2, 40, 0, 1, 1, 0, 1, 1, 0, 1, 0, 1, 0, 0, 1}, new int[]{28, 6, 3, 45, 1, 0, 1, 0, 1, 1, 0, 1, 1, 0, 1}, new int[]{47, 0, 4, 50, 1, 0, 1, 0, 1, 0, 1, 1, 0, 1, 1, 0, 1}, new int[]{36, 0, 6, 56, 1, 0, 0, 1, 0, 0, 1, 1, 0, 1, 1, 1}, new int[]{26, 5, 0, 1, 0, 1, 0, 0, 1, 0, 0, 1, 0, 1, 1, 1, 1}, new int[]{45, 0, 1, 6, 0, 1, 0, 0, 1, 0, 0, 1, 0, 1, 1, 1}, new int[]{34, 0, 2, 11, 0, 1, 1, 0, 0, 1, 0, 0, 1, 0, 1, 1}, new int[]{22, 3, 4, 17, 0, 1, 1, 0, 1, 0, 1, 0, 0, 1, 0, 1}, new int[]{40, 0, 5, 22, 1, 1, 1, 0, 1, 0, 1, 0, 0, 1, 0, 1}, new int[]{30, 8, 6, 27, 0, 1, 1, 0, 1, 0, 1, 1, 0, 0, 1, 0, 1}, new int[]{49, 0, 0, 32, 0, 1, 0, 1, 1, 0, 1, 0, 1, 1, 0, 0, 1}, new int[]{37, 0, 2, 38, 1, 0, 1, 0, 1, 0, 1, 1, 0, 1, 1, 0, 1}, new int[]{27, 5, 3, 43, 1, 0, 0, 1, 0, 0, 1, 1, 0, 1, 1, 0, 1}, new int[]{46, 0, 4, 48, 1, 0, 0, 1, 0, 0, 1, 0, 1, 1, 1, 0, 1}, new int[]{35, 0, 5, 53, 1, 1, 0, 0, 1, 0, 0, 1, 0, 1, 1, 0, 1}, new int[]{23, 4, 0, 59, 1, 1, 0, 1, 0, 1, 0, 0, 1, 0, 1, 0, 1}, new int[]{42, 0, 1, 4, 1, 1, 0, 1, 0, 1, 0, 0, 1, 0, 1, 0, 1}, new int[]{31, 0, 2, 9, 1, 1, 0, 1, 1, 0, 1, 0, 0, 1, 0, 1}, new int[]{21, 2, 3, 14, 0, 1, 0, 1, 1, 0, 1, 0, 1, 0, 1, 0, 1}, new int[]{39, 0, 5, 20, 0, 1, 0, 1, 0, 1, 1, 0, 1, 0, 1, 0, 1}, new int[]{28, 7, 6, 25, 1, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 1, 1}, new int[]{48, 0, 0, 30, 0, 0, 1, 0, 0, 1, 0, 1, 1, 1, 0, 1, 1}, new int[]{37, 0, 1, 35, 1, 0, 0, 1, 0, 0, 1, 0, 1, 1, 0, 1, 1}, new int[]{25, 5, 3, 41, 1, 1, 0, 0, 1, 0, 0, 1, 0, 1, 0, 1, 1}, new int[]{44, 0, 4, 46, 1, 0, 1, 0, 1, 0, 0, 1, 0, 1, 0, 1, 1}, new int[]{33, 0, 5, 51, 1, 0, 1, 1, 0, 1, 0, 0, 1, 0, 1, 0, 1}, new int[]{22, 4, 6, 56, 1, 0, 1, 1, 0, 1, 0, 1, 0, 1, 0, 1}, new int[]{40, 0, 1, 2, 1, 0, 1, 1, 0, 1, 0, 1, 0, 1, 0, 1}, new int[]{30, 9, 2, 7, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 1, 0, 1}, new int[]{49, 0, 3, 12, 0, 1, 0, 0, 1, 0, 1, 1, 1, 0, 1, 0, 1}, new int[]{38, 0, 4, 17, 1, 0, 1, 0, 0, 1, 0, 1, 1, 0, 1, 1}, new int[]{27, 6, 6, 23, 0, 1, 0, 1, 0, 0, 1, 0, 1, 0, 1, 1, 1}, new int[]{46, 0, 0, 28, 0, 1, 0, 1, 0, 0, 1, 0, 1, 0, 1, 1}, new int[]{35, 0, 1, 33, 0, 1, 1, 0, 1, 0, 0, 1, 0, 0, 1, 1}, new int[]{24, 4, 2, 38, 0, 1, 1, 1, 0, 1, 0, 0, 1, 0, 1, 0, 1}, new int[]{42, 0, 4, 44, 0, 1, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1}, new int[]{31, 0, 5, 49, 1, 0, 1, 0, 1, 1, 0, 1, 0, 1, 0, 1}, new int[]{21, 2, 6, 54, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 1, 0, 1}, new int[]{40, 0, 0, 59, 0, 1, 0, 0, 1, 0, 1, 1, 0, 1, 1, 0, 1}, new int[]{28, 6, 2, 5, 1, 0, 1, 0, 0, 1, 0, 1, 0, 1, 1, 1}, new int[]{47, 0, 3, 10, 1, 0, 1, 0, 0, 1, 0, 0, 1, 1, 1, 0, 1}, new int[]{36, 0, 4, 15, 1, 1, 0, 1, 0, 0, 1, 0, 0, 1, 1, 0, 1}, new int[]{25, 5, 5, 20, 1, 1, 1, 0, 1, 0, 0, 1, 0, 0, 1, 1}, new int[]{43, 0, 0, 26, 1, 1, 0, 1, 0, 1, 0, 1, 0, 0, 1, 0, 1}, new int[]{32, 0, 1, 31, 1, 1, 0, 1, 1, 0, 1, 0, 1, 0, 1}, new int[]{22, 3, 2, 36, 0, 1, 1, 0, 1, 0, 1, 1, 0, 1, 0, 1}};
    private static int[][] _SolarDays = {new int[]{0, 31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334, 365, 396}, new int[]{0, 31, 60, 91, 121, 152, 182, 213, 244, 274, 305, 335, 366, 397}};
    private static int FIRSTYEAR = 1936;
    private static int[][] BC = {new int[]{1979, 1982, 1984, 1987, 1990, 1993, 1995, 1998, 2001, 2004, 2006, 2009, 2012, 2014, 2017, 2020, 2023, 2025, 2028}, new int[]{1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1}};
    private static int[][] _MonthDays = {new int[]{31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31}, new int[]{31, 29, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31}};

    private DateUtil() {
    }

    /* JADX WARN: Type inference failed for: r0v1, types: [int[], int[][]] */
    /* JADX WARN: Type inference failed for: r0v3, types: [int[], int[][]] */
    /* JADX WARN: Type inference failed for: r0v6, types: [int[], int[][]] */
    /* JADX WARN: Type inference failed for: r0v8, types: [int[], int[][]] */
    static {
        try {
            formatter1 = new SimpleDateFormat("yyyyMMdd");
            formatter2 = new SimpleDateFormat("yyyy'-'MM'-'dd");
            formatter3 = new SimpleDateFormat("yyyyMMddHHmmss");
            formatter4 = new SimpleDateFormat("yyyy'-'MM'-'dd HH':'mm':'ss");
            formatter5 = new SimpleDateFormat("yyyy'年'MM'月'dd'日' E");
            formatters = new SimpleDateFormat[]{formatter2, formatter1, formatter3, formatter4, formatter5};
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private static int GetLeap(int Year) {
        if (Year % 400 == 0) {
            return 1;
        }
        if (Year % 100 != 0 && Year % 4 == 0) {
            return 1;
        }
        return 0;
    }

    public static ArrayList getWeekEnd(long startday, long endday) {
        ArrayList week = new ArrayList();
        GregorianCalendar day1 = new GregorianCalendar(Integer.parseInt(String.valueOf(startday).substring(0, 4)), Integer.parseInt(String.valueOf(startday).substring(4, 6)) - 1, Integer.parseInt(String.valueOf(startday).substring(6, 8)));
        int rcount = 0;
        do {
            long day = Long.parseLong(convertDateToString(day1.getTime()));
            if (day > endday) {
                break;
            }
            int year = Integer.parseInt(String.valueOf(day).substring(0, 4));
            int month = Integer.parseInt(String.valueOf(day).substring(4, 6));
            int dday = Integer.parseInt(String.valueOf(day).substring(6, 8));
            if (getWeekByDay(year, month, dday) == 0 || getWeekByDay(year, month, dday) == 6) {
                String sweek = "周六";
                if (getWeekByDay(year, month, dday) == 0) {
                    sweek = "周日";
                }
                week.add(String.valueOf(year) + "年" + month + "月" + dday + "日(" + sweek + StringHelper.rightParenthesis);
            }
            day1.add(5, 1);
            rcount++;
        } while (rcount <= 1095);
        return week;
    }

    public static int getWeekByDay(int year, int month, int day) {
        int[] DaysInMonth = {31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31};
        if (IsLeapYear(year)) {
            DaysInMonth[1] = 29;
        }
        int firstdayw = CalcJanuaryFirst(year);
        int sumday = 0;
        for (int i = 0; i < month - 1; i++) {
            sumday += DaysInMonth[i];
        }
        int deferday = ((sumday + day) - 1) % 7;
        int w = (deferday + firstdayw) % 7;
        return w;
    }

    public static String getMonthByWeek(String year, String weekperiod, String weekday) {
        int month = 1;
        int day = 1;
        int[] DaysInMonth = {31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31};
        if (IsLeapYear(Integer.parseInt(year))) {
            DaysInMonth[1] = 29;
        }
        int firstweekday = CalcJanuaryFirst(Integer.parseInt(year));
        int days = ((Integer.parseInt(weekperiod) - 1) * 7) + Integer.parseInt(weekday);
        if (firstweekday != 1) {
            days = ((Integer.parseInt(weekperiod) - 1) * 7) + Integer.parseInt(weekday) + (7 - firstweekday) + 1;
        }
        int tmpw = firstweekday - 1;
        int plusday = 0;
        boolean getflag = false;
        for (int i = 0; i < 12; i++) {
            if (!getflag) {
                int k = 1;
                while (true) {
                    if (k <= DaysInMonth[i]) {
                        if (tmpw == 7) {
                            tmpw = 0;
                        }
                        plusday++;
                        tmpw++;
                        if (plusday != days) {
                            k++;
                        } else {
                            month = i + 1;
                            day = k;
                            getflag = true;
                            break;
                        }
                    }
                }
            }
        }
        String sMonth = String.valueOf(month);
        if (month < 10) {
            sMonth = JqLib.SQL_FALSE + month;
        }
        String sDay = String.valueOf(day);
        if (day < 10) {
            sDay = JqLib.SQL_FALSE + day;
        }
        String returnValue = String.valueOf(sMonth) + sDay;
        return returnValue;
    }

    public static int CalcJanuaryFirst(int year) {
        if (year < 1582) {
            return -1;
        }
        return ((5 + (year - 1582)) + CalcLeapYears(year)) % 7;
    }

    private static int CalcLeapYears(int year) {
        if (year < 1582) {
            return -1;
        }
        int leapYears = (year - 1581) / 4;
        int hundreds = (year - 1501) / 100;
        int leapYears2 = leapYears - hundreds;
        int fourHundreds = (year - 1201) / 400;
        return leapYears2 + fourHundreds;
    }

    public static boolean IsLeapYear(int year) {
        return year % 100 == 0 ? year % 400 == 0 : year % 4 == 0;
    }

    public static String getDateFromLunar(int year, int month, int day) {
        int y = 0;
        int m = 0;
        int d = 0;
        int nDiffYear = year - FIRSTYEAR;
        int nTotalDay = _LunarCal[nDiffYear][0];
        int i = 0;
        while (true) {
            if (i >= BC[0].length) {
                break;
            }
            if (year != BC[0][i]) {
                i++;
            } else {
                month += BC[1][i];
                break;
            }
        }
        for (int i2 = 0; i2 < month - 1; i2++) {
            nTotalDay += _LunarCal[nDiffYear][4 + i2] + 29;
        }
        int nTotalDay2 = nTotalDay + day;
        int nSolarLeap = GetLeap(year);
        int i3 = 13;
        while (true) {
            if (i3 < 0) {
                break;
            }
            if (nTotalDay2 <= _SolarDays[nSolarLeap][i3]) {
                i3--;
            } else {
                d = nTotalDay2 - _SolarDays[nSolarLeap][i3];
                if (i3 <= 11) {
                    y = year;
                    m = i3 + 1;
                } else {
                    y = year + 1;
                    m = i3 - 11;
                }
            }
        }
        String returnValue = String.valueOf(y) + (m < 10 ? JqLib.SQL_FALSE + m : String.valueOf(m)) + (d < 10 ? JqLib.SQL_FALSE + d : String.valueOf(d));
        return returnValue;
    }

    public static int calcDates(long sdate, long edate) {
        Date enddate = convertStringToDate(String.valueOf(sdate));
        Date startdate = convertStringToDate(String.valueOf(edate));
        return Math.round((float) (((((enddate.getTime() - startdate.getTime()) / 1000) / 60) / 60) / 24));
    }

    public static String convertDateString(String dateString) {
        return formatter2.format(convertStringToDate(dateString));
    }

    public static Date convertStringToDate(String dateString) {
        try {
            return formatter1.parse(dateString);
        } catch (Exception unused) {
            return new Date();
        }
    }

    public static String convertDateToString(Date date) {
        return formatter1.format(date);
    }

    public static String convertDateToString1(Date date) {
        return formatter2.format(date);
    }

    public static String convertTimeString(String timeString) {
        return formatter4.format(convertStringToTime(timeString));
    }

    public static String convertTimeString1(String timeString) {
        return formatter1.format(convertStringToDate1(timeString));
    }

    public static Date convertStringToDate1(String timeString) {
        try {
            return formatter2.parse(timeString);
        } catch (Exception unused) {
            return new Date();
        }
    }

    public static Date convertStringToTime(String timeString) {
        try {
            return formatter3.parse(timeString);
        } catch (Exception unused) {
            return new Date();
        }
    }

    public static String convertTimeToString(Date time) {
        return formatter3.format(time);
    }

    public static String getDateWeekString(Date time) {
        return formatter5.format(time);
    }

    public static String getLunarDescrible(int month, int day) {
        String s;
        String returnValue;
        String[] lunmonth = {"正", "正", "二", "三", "四", "五", "六", "七", "八", "九", "十", "十一", "十二"};
        String[] nStr1 = {"日", "一", "二", "三", "四", "五", "六", "七", "八", "九", "十"};
        String[] nStr2 = {"初", "十", "廿", "卅", "\u3000"};
        switch (day) {
            case 10:
                s = "初十";
                break;
            case 20:
                s = "二十";
                break;
            case 30:
                s = "三十";
                break;
            default:
                String s2 = nStr2[day / 10];
                s = String.valueOf(s2) + nStr1[day % 10];
                break;
        }
        try {
            returnValue = String.valueOf(lunmonth[month]) + "月" + s;
        } catch (Exception unused) {
            System.out.println("农历月日表述转换错误!");
            returnValue = String.valueOf(month) + day;
        }
        return returnValue;
    }

    public static String getStrDateFromTime(long mitime) {
        String strDate;
        String strDate2;
        String strDate3;
        String strDate4;
        String strDate5;
        Calendar date = Calendar.getInstance();
        date.setTimeInMillis(mitime);
        int month = date.get(2) + 1;
        int strYear = date.get(1);
        String strDate6 = String.valueOf(Integer.toString(strYear)) + "-";
        if (month >= 10) {
            strDate = String.valueOf(strDate6) + Integer.toString(month) + "-";
        } else {
            strDate = String.valueOf(strDate6) + JqLib.SQL_FALSE + Integer.toString(month) + "-";
        }
        if (date.get(5) >= 10) {
            strDate2 = String.valueOf(strDate) + Integer.toString(date.get(5)) + StringHelper.space;
        } else {
            strDate2 = String.valueOf(strDate) + JqLib.SQL_FALSE + Integer.toString(date.get(5)) + StringHelper.space;
        }
        if (date.get(11) >= 10) {
            strDate3 = String.valueOf(strDate2) + Integer.toString(date.get(11)) + ":";
        } else {
            strDate3 = String.valueOf(strDate2) + JqLib.SQL_FALSE + Integer.toString(date.get(11)) + ":";
        }
        if (date.get(12) >= 10) {
            strDate4 = String.valueOf(strDate3) + Integer.toString(date.get(12)) + ":";
        } else {
            strDate4 = String.valueOf(strDate3) + JqLib.SQL_FALSE + Integer.toString(date.get(12)) + ":";
        }
        if (date.get(13) >= 10) {
            strDate5 = String.valueOf(strDate4) + Integer.toString(date.get(13));
        } else {
            strDate5 = String.valueOf(strDate4) + JqLib.SQL_FALSE + Integer.toString(date.get(13));
        }
        return strDate5;
    }

    public static String getStrDateFromMitime(long mitime) {
        String strDate;
        String strDate2;
        String strDate3;
        String strDate4;
        Calendar date = Calendar.getInstance();
        date.setTimeInMillis(mitime);
        int strMonth = date.get(2) + 1;
        int strYear = date.get(1);
        String strDate5 = Integer.toString(strYear);
        if (strMonth >= 10) {
            strDate = String.valueOf(strDate5) + Integer.toString(strMonth);
        } else {
            strDate = String.valueOf(strDate5) + JqLib.SQL_FALSE + Integer.toString(strMonth);
        }
        if (date.get(5) >= 10) {
            strDate2 = String.valueOf(strDate) + Integer.toString(date.get(5));
        } else {
            strDate2 = String.valueOf(strDate) + JqLib.SQL_FALSE + Integer.toString(date.get(5));
        }
        if (date.get(11) >= 10) {
            strDate3 = String.valueOf(strDate2) + Integer.toString(date.get(11));
        } else {
            strDate3 = String.valueOf(strDate2) + JqLib.SQL_FALSE + Integer.toString(date.get(11));
        }
        if (date.get(12) >= 10) {
            strDate4 = String.valueOf(strDate3) + Integer.toString(date.get(12));
        } else {
            strDate4 = String.valueOf(strDate3) + JqLib.SQL_FALSE + Integer.toString(date.get(12));
        }
        return strDate4;
    }

    public static String date2String(Date date) {
        return formatter2.format(date);
    }

    public static String date2String(long time) {
        return date2String(new Date(time));
    }

    public static String dateTime2String(Date dateTime) {
        return formatter4.format(dateTime);
    }

    public static String dateTime2String(long dateTime) {
        return dateTime2String(new Date(dateTime));
    }

    public static int getDaysInAMonth(int year, int month) {
        return _MonthDays[IsLeapYear(year) ? (char) 1 : (char) 0][month];
    }

    public static Date tryParserDateString(String dateString) {
        if (dateString == null || dateString.length() == 0) {
            return null;
        }
        for (int i = 0; i < formatters.length; i++) {
            try {
                return formatters[i].parse(dateString);
            } catch (ParseException unused) {
            }
        }
        return null;
    }
}
